Django CMS Plugins
******************

.. automodule:: media_tree.contrib.cms_plugins
   :members:

.. Note::
   Of course you can also create your own models and plugins using ``FileNode``
   objects. Please take a look at :ref:`fields` and :ref:`custom-plugins-howto`
   for more information on how to integrate Media Tree with your own applications.
 
.. automodule:: media_tree.contrib.cms_plugins.media_tree_listing
   :members:

.. automodule:: media_tree.contrib.cms_plugins.media_tree_image
   :members:

.. automodule:: media_tree.contrib.cms_plugins.media_tree_slideshow
   :members:

.. automodule:: media_tree.contrib.cms_plugins.media_tree_gallery
   :members:
